@@ -8,6 +8,8 @@ from .redditor import Redditor
 class WikiPage(RedditBase):
     """An individual WikiPage object."""
 
+    __hash__ = RedditBase.__hash__
+
     @staticmethod
     def _revision_generator(subreddit, url, generator_kwargs):
         for revision in ListingGenerator(subreddit._reddit, url,
@@ -31,10 +33,6 @@ class WikiPage(RedditBase):
         return isinstance(other, self.__class__) and \
             str(self).lower() == str(other).lower()
 
-    def __hash__(self):
-        """Return the hash of the current instance."""
-        return super(WikiPage, self).__hash__()
-
     def __init__(self, reddit, subreddit, name, revision=None, _data=None):
         """Construct an instance of the WikiPage object.
 
@@ -96,6 +94,13 @@ class WikiPage(RedditBase):
            for item in reddit.subreddit('test').wiki['praw_test'].revisions():
                print(item)
 
+        To get :class:`.WikiPage` objects for each revision:
+
+        .. code:: python
+
+           for item in reddit.subreddit('test').wiki['praw_test'].revisions():
+               print(item['page'])
+
         """
         url = API_PATH['wiki_page_revisions'].format(subreddit=self.subreddit,
                                                      page=self.name)
