@@ -14,7 +14,7 @@ from prawcore import (Authorizer, DeviceIDAuthorizer, ReadOnlyAuthorizer,
 
 from .exceptions import ClientException
 from .config import Config
-from .const import __version__, API_PATH, USER_AGENT_FORMAT
+from .const import __version__, API_PATH, USER_AGENT_FORMAT, configparser
 from .objector import Objector
 from . import models
 
@@ -72,7 +72,8 @@ class Reddit(object):
         """Handle the context manager close."""
         pass
 
-    def __init__(self, site_name=None, **config_settings):
+    def __init__(self, site_name=None, requestor_class=None,
+                 requestor_kwargs=None, **config_settings):
         """Initialize a Reddit instance.
 
         :param site_name: The name of a section in your ``praw.ini`` file from
@@ -83,6 +84,10 @@ class Reddit(object):
             ``None``, then the site name will be looked for in the environment
             variable praw_site. If it is not found there, the DEFAULT site will
             be used.
+        :param requestor_class: A class that will be used to create a
+            requestor. If not set, use ``prawcore.Requestor`` (default: None).
+        :param requestor_kwargs: Dictionary with additional keyword arguments
+            used to initialize the requestor (default: None).
 
         Additional keyword arguments will be used to initialize the
         :class`.Config` object. This can be used to specify configuration
@@ -95,12 +100,45 @@ class Reddit(object):
         * client_secret (for installed applications set this value to ``None``)
         * user_agent
 
+        The ``requestor_class`` and ``requestor_kwargs`` allow for
+        customization of the requestor :class`.Reddit` will use. This allows,
+        e.g., easily adding behavior to the requestor or wrapping its
+        :class`Session` in a caching layer. Example usage:
+
+        .. code-block:: python
+
+           import json, betamax, requests
+
+           class JSONDebugRequestor(Requestor):
+               def request(self, *args, **kwargs):
+                   response = super().request(*args, **kwargs)
+                   print(json.dumps(response.json(), indent=4))
+                   return response
+
+           my_session = betamax.Betamax(requests.Session())
+           reddit = Reddit(..., requestor_class=JSONDebugRequestor,
+                           requestor_kwargs={'session': my_session})
+
         """
         self._core = self._authorized_core = self._read_only_core = None
         self._objector = None
         self._unique_counter = 0
-        self.config = Config(site_name or os.getenv('praw_site') or 'DEFAULT',
-                             **config_settings)
+
+        try:
+            config_section = site_name or os.getenv('praw_site') or 'DEFAULT'
+            self.config = Config(config_section, **config_settings)
+        except configparser.NoSectionError as exc:
+            help_message = ('You provided the name of a praw.ini '
+                            'configuration which does not exist.\n\nFor help '
+                            'with creating a Reddit instance, visit\n'
+                            'https://praw.readthedocs.io/en/latest/code_overvi'
+                            'ew/reddit_instance.html\n\n'
+                            'For help on configuring PRAW, visit\n'
+                            'https://praw.readthedocs.io/en/latest/getting_sta'
+                            'rted/configuration.html')
+            if site_name is not None:
+                exc.message += '\n' + help_message
+            raise
 
         required_message = ('Required configuration setting {!r} missing. \n'
                             'This setting can be provided in a praw.ini file, '
@@ -113,12 +151,12 @@ class Reddit(object):
         if self.config.client_secret is self.config.CONFIG_NOT_SET:
             raise ClientException(required_message.format('client_secret') +
                                   '\nFor installed applications this value '
-                                  'must be set to None via a keyword arugment '
+                                  'must be set to None via a keyword argument '
                                   'to the `Reddit` class constructor.')
 
         self._check_for_update()
         self._prepare_objector()
-        self._prepare_prawcore()
+        self._prepare_prawcore(requestor_class, requestor_kwargs)
 
         self.auth = models.Auth(self, None)
         """An instance of :class:`.Auth`.
@@ -251,6 +289,9 @@ class Reddit(object):
                     'Listing': models.Listing,
                     'LiveUpdate': models.LiveUpdate,
                     'LiveUpdateEvent': models.LiveThread,
+                    'ModmailAction': models.ModmailAction,
+                    'ModmailConversation': models.ModmailConversation,
+                    'ModmailMessage': models.ModmailMessage,
                     'UserList': models.RedditorList,
                     'modaction': models.ModAction,
                     'more': models.MoreComments,
@@ -258,9 +299,15 @@ class Reddit(object):
         for kind, klass in mappings.items():
             self._objector.register(kind, klass)
 
-    def _prepare_prawcore(self):
-        requestor = Requestor(USER_AGENT_FORMAT.format(self.config.user_agent),
-                              self.config.oauth_url, self.config.reddit_url)
+    def _prepare_prawcore(self, requestor_class=None, requestor_kwargs=None):
+        requestor_class = requestor_class or Requestor
+        requestor_kwargs = requestor_kwargs or {}
+
+        requestor = requestor_class(
+            USER_AGENT_FORMAT.format(self.config.user_agent),
+            self.config.oauth_url, self.config.reddit_url,
+            **requestor_kwargs)
+
         if self.config.client_secret:
             self._prepare_trusted_prawcore(requestor)
         else:
@@ -290,16 +337,20 @@ class Reddit(object):
         read_only_authorizer = DeviceIDAuthorizer(authenticator)
         self._core = self._read_only_core = session(read_only_authorizer)
 
-    def comment(self, id):  # pylint: disable=invalid-name,redefined-builtin
+    def comment(self,  # pylint: disable=invalid-name
+                id=None,  # pylint: disable=redefined-builtin
+                url=None):
         """Return a lazy instance of :class:`~.Comment` for ``id``.
 
         :param id: The ID of the comment.
 
+        :param url: A permalink pointing to the comment.
+
         .. note:: If you want to obtain the comment's replies, you will need to
                   call :meth:`.refresh` on the returned :class:`.Comment`.
 
         """
-        return models.Comment(self, id=id)
+        return models.Comment(self, id=id, url=url)
 
     def domain(self, domain):
         """Return an instance of :class:`.DomainListing`.
@@ -320,11 +371,13 @@ class Reddit(object):
         data = self.request('GET', path, params=params)
         return self._objector.objectify(data)
 
-    def info(self, fullnames):
-        """Fetch information about each item in ``fullnames``.
+    def info(self, fullnames=None, url=None):
+        """Fetch information about each item in ``fullnames`` or from ``url``.
 
-        :param fullnames: A list of fullnames for a comment, submission, or
-            subreddit.
+        :param fullnames: A list of fullnames for comments, submissions, and/or
+            subreddits.
+        :param url: A url (as a string) to retrieve lists of link submissions
+            from.
         :returns: A generator that yields found items in their relative order.
 
         Items that cannot be matched will not be generated. Requests will be
@@ -334,18 +387,47 @@ class Reddit(object):
                   to obtain its replies, you will need to call :meth:`.refresh`
                   on the yielded :class:`.Comment`.
 
+        .. note:: When using the URL option, it is important to be aware that
+                  URLs are treated literally by Reddit's API. As such, the URLs
+                  "youtube.com" and "https://www.youtube.com" will provide a
+                  different set of submissions.
+
         """
-        if not isinstance(fullnames, list):
-            raise TypeError('fullnames must be a list')
+        if bool(fullnames) == bool(url):
+            raise TypeError('Either `fullnames` or `url` must be provided.')
 
-        def generator():
-            for position in range(0, len(fullnames), 100):
-                fullname_chunk = fullnames[position:position + 100]
-                params = {'id': ','.join(fullname_chunk)}
-                for result in self.get(API_PATH['info'], params=params):
-                    yield result
+        elif fullnames:
+            if not isinstance(fullnames, list):
+                raise TypeError('fullnames must be a list')
 
-        return generator()
+            def generator():
+                for position in range(0, len(fullnames), 100):
+                    fullname_chunk = fullnames[position:position + 100]
+                    params = {'id': ','.join(fullname_chunk)}
+                    for result in self.get(API_PATH['info'], params=params):
+                        yield result
+
+            return generator()
+
+        else:
+            try:
+                params = {'url': url}
+                url_list = [result for result in
+                            self.get(API_PATH['info'], params=params)]
+                return url_list
+            except Exception:
+                raise TypeError('Invalid URL or no posts exist')
+
+    def patch(self, path, data=None):
+        """Return parsed objects returned from a PATCH request to ``path``.
+
+        :param path: The path to fetch.
+        :param data: Dictionary, bytes, or file-like object to send in the body
+            of the request (default: None).
+
+        """
+        data = self.request('PATCH', path, data=data)
+        return self._objector.objectify(data)
 
     def post(self, path, data=None, files=None, params=None):
         """Return parsed objects returned from a POST request to ``path``.
@@ -353,7 +435,7 @@ class Reddit(object):
         :param path: The path to fetch.
         :param data: Dictionary, bytes, or file-like object to send in the body
             of the request (default: None).
-        :param files: Dictionary, filename to file (like) object mappin
+        :param files: Dictionary, filename to file (like) object mapping
             (default: None).
         :param params: The query parameters to add to the request (default:
             None).
@@ -396,7 +478,7 @@ class Reddit(object):
             None).
         :param data: Dictionary, bytes, or file-like object to send in the body
             of the request (default: None).
-        :param files: Dictionary, filename to file (like) object mappin
+        :param files: Dictionary, filename to file (like) object mapping
             (default: None).
 
         """
@@ -408,7 +490,8 @@ class Reddit(object):
         """Return a lazy instance of :class:`~.Submission`.
 
         :param id: A reddit base36 submission ID, e.g., ``2gmzqe``.
-        :param url: A URL supported by :meth:`.id_from_url`.
+        :param url: A URL supported by
+            :meth:`~praw.models.Submission.id_from_url`.`.
 
         Either ``id`` or ``url`` can be provided, but not both.
 
